function a = fullstate_plainq_init(a, info)
%Initializes the full-state plain Q-learning algorithm
%  A = FULLSTATE_PLAINQ_INIT(A, INFO)
%  Creates the structures required for the full-state plain Q-learning
%  algorithm to run. Initializes the Q table and an eligibility trace as
%  flat vectors. Values on the info parameters:
%   statespacesize      - the state space size
% 
%
%  See also agent_initlearn, fullstate_plainq

%  Author:      Lucian Busoniu
%  Version:     1.0
%  History:


% Check states and actions
if any(info.statespacesize(:, 1) ~= 1) || ...
        a.indices(5) < a.indices(6) || ...
        info.actionspacesize(a.indices(5), 1) ~= 1
    error('fullstate_plainq() only supports discrete states and actions, with 1 action variable');
else
    a.actionscount = info.actionspacesize(info.imap(5), 2);
end;

% we care about the whole world size
a.qsize = [a.actionscount info.statespacesize(:, 2)'];
a.Q = zeros(prod(a.qsize), 1);
a.E = a.Q;

a.volatile = {'E'};

% returning a
% END fullstate_plainq_init() =============================================