function a = minimaxq2_init(a, info)
%Initializes the minimax Q learning algorithm
%  A = MINIMAXQ2_INIT(A, INFO)
%  Creates the structures required for the minimax Q learning algorithm to
%  run.
%  Values on the info parameters:
%   statespacesize      - the state space size
%   actionspacesizes    - the sizes of the action spaces for all agents
% 
%
%  See minimaxq2, agent_initlearn


% Check states and actions
if any(info.statespacesize(:, 1) ~= 1) || ...
        a.indices(5) < a.indices(6) || ...  % this should check for all agents
        any(info.actionspacesize(:, 1) ~= 1)
    error('minimaxq2() only supports discrete states and actions, with 1 action variable');
elseif size(info.actionspacesize, 1) ~= 2,
     error('minimaxq2() only works for two-agent games');
else
    a.actionscount = info.actionspacesize(info.imap(5), 2);
end;


% init sizes
m = a.actionscount;
ss = info.statespacesize(:, 2)';

a.sizes.act = info.actionspacesize(:, 2)';
a.sizes.expact = prod(a.sizes.act);
a.sizes.q = [a.sizes.act ss];
a.sizes.pi = [m ss];

a.Q = zeros(prod(a.sizes.q), 1);
a.E = a.Q;
a.PI = 1/m * ones(prod(a.sizes.pi), 1);

M = zeros(m, 1);
a.lp.m = m;
a.lp.f = [M; -1];
% just a placeholder for the inequality constraints
% which will contain the actual coefficients
a.lp.A = zeros(a.sizes.act); a.lp.A(:, end+1) = 1;
a.lp.b = M;
a.lp.Aeq = [1+M' 0];
a.lp.beq = 1;
a.lp.lb = [M; -Inf];
a.lp.ub = [1+M; Inf];
a.lp.options = optimset('LargeScale', 'off', 'Display', 'off');

% which of the action components corresponds to this agent
a.lp.aind = a.indices(5);


a.volatile = {'Q', 'E', 'lp'};

% returning a
% END teamq_init()
% ========================================================