function a = plainq_init(a, info)
%Initializes the plain Q learning algorithm
%  A = PLAINQ_INIT(A, INFO)
%  Creates the structures required for the plain Q learning algorithm to
%  run. Initializes the Q table and an eligibility trace as flat vectors.
%  Values on the info parameters:
%   statespacesize      - (optional) if given, will be used for efficiently
%       initializing the Q-table for the agent
% 
%
%  See also agent_initlearn, plainq

%  Author:      Lucian Busoniu
%  Version:     1.0
%  History:

% Check states and actions
if any(info.statespacesize(a.indices(1):a.indices(2), 1) ~= 1) || ...
        a.indices(5) < a.indices(6) || ...
        info.actionspacesize(a.indices(5), 1) ~= 1
    error('plainq() only supports discrete states and actions, with 1 action variable');
else
    a.actionscount = info.actionspacesize(a.indices(5), 2);
end;

a.qsize = [a.actionscount info.statespacesize(a.indices(1) : a.indices(2), 2)'];
a.Q = zeros(prod(a.qsize), 1);
a.E = a.Q;

a.volatile = {'E'};

% returning a
% END plainq_init() ========================================================