% Demonstration of using batch experiments
% This script demonstrates the use of the MARL toolbox to run batch
% experiments and process their results. The experiment batch involves
% the comparison of Q-learning and full-state Q-learning on a 5x5
% gridworld, and is explained in detail in Chapter 5 of the documentation.

% Turn on commands echo to show how things are done
echo on;

% This script demonstrates the use of the MARL toolbox to run batch
% experiments and process their results. The experiment batch involves
% the comparison of Q-learning and full-state Q-learning on a 5x5
% gridworld, and is explained in detail in Chapter 5 of the documentation.
%

% Create the experiment config structure
% This is slightly different from what is listed in the documentation:
% We do only 5 runs, and activate intermediate convergence plots
NRUNS = 5;
expc = {struct(...
        ... % world arguments
        'worldtype', 'gridworld', ...
        'worldargs', {{[], 'Square', [5 5]', [5 5; 1 5]', [1 1; 5 1]', [3 1; 3 5]'}}, ...
        ... % learning parameters and agent learning parameters
        ... % note we do not allow convergence to stop learning
        'lp', struct('trials', 130, 'maxiter', 300, 'convgoal', -1, 'avgtrials', 30), ...
        ... % agent count, learning parameters, and functions
        'agn', 2, ...
        'aglp', struct('alpha', .3, 'gamma', .95, 'lambda', .5, 'epsilon', .3), ...
        ... % double braces to make agfun a single value
        'agfun', {{'plainq', 'greedyact', 'randomexplore'}}, ...
        ... % options structure
        'options', struct('nruns', NRUNS, 'show', 'off', 'convplot', 'on', 'plotpause', 3, 'label', 'Plain Q') ...
    ), struct(...
        ... % for the second experiment, anything that is not specified
        ... % remains the same as configured for the first experiment
        'lp', struct('trials', 130, 'maxiter', 400, 'convgoal', -1, 'avgtrials', 30), ...
        'agfun', {{'fullstate_plainq', 'fullstate_greedyact', 'randomexplore'}}, ...
        'options', struct('nruns', NRUNS, 'show', 'off', 'convplot', 'on', 'plotpause', 3, 'label', 'Complete-state Q') ...
    )};
pause;

% Run the experiment; note the experiment logs at the Matlab console
fname = 'docexample_q_fullstateq';
runexp(expc, fname, pwd, NRUNS, 'off');
pause;

% Process the experiment in REPLAY mode
processexp(fname, 'replay');
pause;

% Process now the experiment in PLOT mode to obtain compared
% convergence plots
% It appears that full-state Q-learning learns slower and obtains worse
% policies than ordinary Q-learning
processexp(fname, 'plot');
pause;

% Cleanup
delete([fname '.mat']);
close(gcf);
echo off;
