% Demonstration of plain Q-learning on a 5x5 gridworld
% This script demonstrates the direct use of the MARL toolbox to run
% learning experiments, examine learning statistics and replay learned
% behaviour. The experiment involves two Q-learning agents on a 5x5
% gridworld, and is explained in detail in Chapter 4 of the documentation.

% Turn on commands echo to show how things are done
echo on;

% This script demonstrates the direct use of the MARL toolbox to run
% learning experiments, examine learning statistics and replay learned
% behaviour. The experiment involves two Q-learning agents on a 5x5
% gridworld, and is explained in detail in Chapter 4 of the documentation.
%


% Setup and create agents
alp.alpha= .3; alp.gamma = .95; alp.lambda = .5; alp.epsilon = .5;
red = agent(1, alp, 'plainq', 'greedyact', 'randomexplore');
green = agent(2, alp, 'plainq', 'greedyact', 'randomexplore');
agents = {red, green};
pause;

% Create gridworld
                       % name,   size,   goalpos,     initpos,     obstacles
gw = gridworld(agents, 'Square', [5 5]', [5 5; 1 5]', [1 1; 5 1]', [3 1; 3 5]');
pause;

% Setup learning and agent parameters
% Enable online plot of convergence
lp.trials = 100; lp.maxiter = 300; lp.convgoal = .25; lp.avgtrials = 10; lp.showconv = 1;
pause;

% Run learning with created agents on gridworld
% First, show gridworld so that we see what is happenning
gw = gridworld_display(gw); 
[gw, agents, stats] = learn(gw, agents, lp);
pause;

% Show convergence plot
fhandle = figure; stairs(1:stats.trials, stats.iter);
pause;

% Replay learned behaviour
[gw, agents] = replay(gw, agents);
pause;

% Cleanup
gw = gridworld_destroy(gw);
close(fhandle);
echo off;