function gw = gridworld_obstacles(gw)
%Interactively places obstacles in the grid world
%  GW = GRIDWORLD_OBSTACLES(GW)
%  Allows for interactive placement of obstacles in the gridworld, using
%  the pointing device.
% 
%  Parameters:
%   GW          - the grid world
%  Returns:
%   GW          - the updated gridworld
%
%
%  See also gridworld

%  Author:      Lucian Busoniu
%  Version:     1.0
%  History:


% first thing - show view
visible = gridworldview_isvisible(gw.view);  % store state
gw = gridworld_display(gw);
v = gw.view;

% create coords grid
xlines = linspace(0, v.guiw, v.width + 1);
ylines = linspace(0, v.guih, v.height + 1);

done = 0;       % we loop asking for points until user right-clicks
while ~done,
    [x y button] = ginput(1);   % one point at a time
    if button == 3,             % just set termination flag
        done = 1;
    else
        % find out within which cell the click took place
        c = 0; r = 0;
        for i = 1 : v.width,
            if (xlines(i) <= x) && (x < xlines(i + 1)), c = i; end;
        end;
        for i = 1 : v.height,
            if (ylines(i) <= y) && (y < ylines(i + 1)), r = i; end;
        end;
        
        if c && r,      % click within bounds
            if gw.grid(c, r) == 0,          % place obstacle
                gw.grid(c, r) = -1;
            elseif gw.grid(c, r) == -1,     % remove obstacle
                gw.grid(c, r) = 0;
            end;
            % update view
            gw = gridworld_display(gw, 1, [c c r r]);
        end;            % END within bounds test
    end;                % END left or middle click test
end;        % END main iteration

gw.view = v;

% hide if previously hidden
if ~visible, gw = gridworld_display(gw, 0); end;

% returning gw

% END gridworld_obstacles() ================================================