function [gw, stateviews] = gridworld_reset(gw, restype)
%Resets the gridworld to its initial state and reports this state
%  [GW, STATEVIEWS] = GRIDWORLD_RESET(GW, RESTYPE)
%  Resets the gridworld to its initial state, after a trial has ended.
%  Returns the state of the world as viewed by all the agents within.
%  All agents will see the true state of the gridworld.
%
%  Parameters:
%   GW          - the gridworld
%   RESTYPE     - the reset type (optional). Currently ignored.
%  Returns:
%   GW          - the reset gridworld
%   STATEVIEWS  - the state views, one agent view per column
%
%
%  See also gridworld, gridworld_advance

%  Author:      Lucian Busoniu
%  Version:     1.0
%  History:


% flatten grid, remove any agents and place them in their start positions
grid = gw.grid(:);
grid(find(grid > 0 & grid < 1000)) = 0;

prevstate = gw.state;
if ~isempty(gw.initpos),
    % reset to deterministic initial positions
    grid(sub2ind(gw.size, gw.initialstate(1, :), gw.initialstate(2, :))) = gw.aidmap;
    gw.state = gw.initialstate;
else
    % init random positions
    for i = 1:gw.acount,
        grid = reshape(grid, gw.size);
        pos = ceil(rand(1, 2) .* gw.size);
        while grid(pos(1), pos(2)) ~= 0, pos = ceil(rand(1, 2) .* gw.size);
        end;
        grid(pos(1), pos(2)) = gw.aidmap(i);
        gw.state(:, i) = pos';
    end;
end;

gw.grid(:) = grid;
if gridworldview_isvisible(gw.view),    % update view
    xs = [gw.state(1, :) prevstate(1, :)];
    ys = [gw.state(2, :) prevstate(2, :)];
    gw = gridworld_display(gw, 1, [min(xs) max(xs) min(ys) max(ys)]);
else
    gw.view.tainted = 1;
end;

stateviews = repmat(gw.state(:), 1, gw.acount);

% returning gw, stateviews
% END gridworld_state() ===================================================