function gw = robotsgw_display(gw, visible)
%Shows or hides the grid world view
%  V = ROBOTSGW_DISPLAY(GW[, VISIBLE])
%  Shows or hides the grid word view. If the UPDATE argument is present, the
%  view is updated to be consistent with the world state. If on the other hand
%  the argument is not present, but the view needs to be shown and knows it is
%  tainted (not consistent with the state of the world) an automatic complete
%  update will be performed.
% 
%  Parameters:
%   GW          - the grid world
%   VISIBLE     - (optional) whether the view should be shown (1) or
%               hidden (0). By default, the view remain as it were.
%  Returns:
%   GW          - the updated gridworld
%
%
%  See also robotsgwview, robotsgw_advance

%  Author:      Lucian Busoniu
%  Version:     1.0
%  History:

% note that the view can still be hidden explicitly
if nargin < 2, visible = gw.view.visible || (gw.trialsk >= gw.view.cfg.showafter); end;

if visible,
    v = gw.view;
%     figure(v.gui);      % make visible, bring to top
    set(v.gui, 'Visible', 'on');
    % change agent positions
    [i, j] = find((gw.grid > 0) & (gw.grid < 1000));
    for k = 1:gw.acount,
        aid = gw.aidmap(k);
        % get the image handle for the agent
        imgh = v.agentimages(find(v.agentimages(:, 1) == aid, 1), 2);
        % find its position on the grid
        [i, j] = find(gw.grid == aid, 1);
        if isempty(i),
            % agent not visible on the grid
            set(imgh, 'Visible', 'off');
        else
            % change position, ensure it's visible
            set(imgh, 'XData', v.xcenters(j, i) - v.CONTENT_SIZE/2, ...
              'YData', v.ycenters(j, i) - v.CONTENT_SIZE/2, 'Visible', 'on');
        end;
    end;
    drawnow;       % show
    % in Windows, replace by pause(seconds)
    % if the robotsgw painting engine "hangs" during updates
    if gw.trialsk > v.cfg.slowdownafter,
        pause(v.cfg.slowdownpause);
    end;
    gw.view.visible = 1;
else
    set(gw.view.gui, 'Visible', 'off');
    gw.view.visible = 0;
end;

% returning gw

% END robotsgwview_display() =============================================