function gw = rrgw_display(gw, visible)
%Shows or hides the grid world view
%  V = RRGW_DISPLAY(GW[, VISIBLE])
%  Shows or hides the grid word view. If the UPDATE argument is present, the
%  view is updated to be consistent with the world state. If on the other hand
%  the argument is not present, but the view needs to be shown and knows it is
%  tainted (not consistent with the state of the world) an automatic complete
%  update will be performed.
% 
%  Parameters:
%   GW          - the grid world
%   VISIBLE     - (optional) whether the view should be shown (1) or
%               hidden (0). By default, the view remain as it were.
%  Returns:
%   GW          - the updated gridworld
%
%
%  See also rrgwview, rrgw_advance

%  Author:      Lucian Busoniu
%  Version:     1.0
%  History:

% note that the view can still be hidden explicitly
if nargin < 2, visible = gw.view.visible || (gw.trialsk >= gw.view.cfg.showafter); end;

if visible,
    v = gw.view;
%     figure(v.gui);      % make visible, bring to top
    set(v.gui, 'Visible', 'on');
    % change agent positions
    for k = 1:gw.agn,
        % get the image handle for the agent
        imgh = v.agentimages(k);
        % change its position on the grid
        [i, j] = find(gw.grid == k, 1);
        set(imgh, 'XData', v.xcenters(j, i) - v.CONTENT_SIZE/2, ...
          'YData', v.ycenters(j, i) - v.CONTENT_SIZE/2, 'Visible', 'on');
    end;
    for k = 1:gw.targn,
        % get the image handle for the target
        imgh = v.targetimages(k);
        % change position
        [i, j] = find(gw.grid == 1000+k, 1);
        set(imgh, 'XData', v.xcenters(j, i) - v.CONTENT_SIZE/2, ...
          'YData', v.ycenters(j, i) - v.CONTENT_SIZE/2, 'Visible', 'on');
    end;        
    drawnow;       % show
    % in Windows, replace by pause(seconds)
    % if the painting engine "hangs" during updates
    if gw.trialsk > v.cfg.slowdownafter,
        pause(v.cfg.slowdownpause);
    end;
    gw.view.visible = 1;
else
    set(gw.view.gui, 'Visible', 'off');
    gw.view.visible = 0;
end;

% returning gw

% END rrgwview_display() =============================================