function [info] = robotsgw_info(gw)
%Returns information about the robotsgw
%  [INFO] = robotsgw_INFO(GW)
%  Parameters:
%   GW          - the robotsgw
%  Returns:
%   INFO        - the world information structure
%
%  For the contents of the INFO structure, see world_info
%
%
%  See also robotsgw, agent_init

%  Author:      Lucian Busoniu
%  Version:     1.0
%  History:

DISCRETE = 1;
lockcomb = 1+gw.agn;    % number of lock points for each agent, plus no lock

info.imaps = [1 3, 1 0, 1 1, 1]';
for i = 2:gw.agn,
    info.imaps(:, end+1) = info.imaps(:, end) + [3 3, 0 0, 1 1, 1]';
end;
info.statespacesize = repmat(...
    [DISCRETE gw.cfg.size(1); DISCRETE gw.cfg.size(2); DISCRETE lockcomb], ...
    gw.agn, 1);
info.actionspacesize = repmat([DISCRETE 5], gw.agn, 1);
info.statenames = {};
info.actionnames = {};
for i = 1:gw.agn,
    info.statenames{end + 1} = ['x' num2str(i)];
    info.statenames{end + 1} = ['y' num2str(i)];
    info.statenames{end + 1} = ['lock' num2str(i)];
    info.actionnames{end + 1} = ['dir' num2str(i)];
end;


% END robotsgw_indexmaps() ================================================