function [gw, stateviews] = robotsgw_reset(gw, restype)
%Resets the robotsgw to its initial state and reports this state
%  [GW, STATEVIEWS] = robotsgw_RESET(GW, [RESTYPE])
%  Resets the robotsgw to its initial state, after a trial has ended.
%  Returns the state of the world as viewed by all the agents within.
%  All agents will see the true state of the robotsgw.
%
%  Parameters:
%   GW          - the robotsgw
%   RESTYPE     - (optional) the reset type, 0 soft, 1 hard. Default 0.
%  Returns:
%   GW          - the reset robotsgw
%   STATEVIEWS  - the state views, one agent view per column
%
%
%  See also robotsgw, robotsgw_advance

%  Author:      Lucian Busoniu
%  Version:     1.0
%  History

if nargin < 2, restype = 0; end;

% reset everything (up to random agent positions)
gw.grid = gw.grid0;
gw.state = gw.state0;

% random init, if such configured
% agents can be restarted only on empty positions
if isempty(gw.cfg.initpos),
    for i = 1:gw.agn,
        pos = ceil(rand(2, 1) .* gw.cfg.size);
        while gw.grid(pos(1), pos(2)) ~= 0, pos = ceil(rand(2, 1) .* gw.cfg.size);
        end;
        gw.grid(pos(1), pos(2)) = gw.aidmap(i);
        gw.state(:, i) = pos;
    end;
end;

gw.lockflags = 0*gw.lockflags;      % noone is locked after reset
gw.lockpos = gw.lockpos0;

gw = rrgw_display(gw);

% current state is positions of each agent followed by its lock index + 1
x = [gw.state(:, 1:gw.agn); ones(1, gw.agn)];

stateviews = repmat(x(:), 1, gw.agn);

% increment trials clock
if restype == 0,
    gw.trialsk = gw.trialsk + 1;
elseif restype > 0,
    gw.k = 0;
    gw.trialsk = 0;
end;
gw.kt = 0;      % within-trial clock

% returning gw, stateviews
% END robotsgw_state() ===================================================